==> qt6_applications-6.0.3.2.2-py3-none-macosx_10_14_x86_64.whl: qt6_applications-6.0.3.2.2.data/purelib/qt6_applications/Qt/lib/cmake/Qt6LinguistTools/Qt6LinguistToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::lconvert" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lconvert APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lconvert PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lconvert"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lconvert )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lconvert "${_IMPORT_PREFIX}/bin/lconvert" )

# Import target "Qt6::lprodump" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lprodump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lprodump PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lprodump"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lprodump )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lprodump "${_IMPORT_PREFIX}/bin/lprodump" )

# Import target "Qt6::lrelease" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lrelease APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lrelease PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lrelease"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lrelease )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lrelease "${_IMPORT_PREFIX}/bin/lrelease" )

# Import target "Qt6::lrelease-pro" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lrelease-pro APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lrelease-pro PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lrelease-pro"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lrelease-pro )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lrelease-pro "${_IMPORT_PREFIX}/bin/lrelease-pro" )

# Import target "Qt6::lupdate" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lupdate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lupdate PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lupdate"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lupdate )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lupdate "${_IMPORT_PREFIX}/bin/lupdate" )

# Import target "Qt6::lupdate-pro" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lupdate-pro APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lupdate-pro PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lupdate-pro"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lupdate-pro )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lupdate-pro "${_IMPORT_PREFIX}/bin/lupdate-pro" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> qt6_applications-6.1.0.2.2-py3-none-macosx_10_14_x86_64.whl: qt6_applications-6.1.0.2.2.data/purelib/qt6_applications/Qt/lib/cmake/Qt6LinguistTools/Qt6LinguistToolsTargets-relwithdebinfo.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RelWithDebInfo".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "Qt6::lconvert" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lconvert APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lconvert PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lconvert"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lconvert )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lconvert "${_IMPORT_PREFIX}/bin/lconvert" )

# Import target "Qt6::lprodump" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lprodump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lprodump PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/./libexec/lprodump"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lprodump )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lprodump "${_IMPORT_PREFIX}/./libexec/lprodump" )

# Import target "Qt6::lrelease" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lrelease APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lrelease PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lrelease"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lrelease )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lrelease "${_IMPORT_PREFIX}/bin/lrelease" )

# Import target "Qt6::lrelease-pro" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lrelease-pro APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lrelease-pro PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/./libexec/lrelease-pro"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lrelease-pro )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lrelease-pro "${_IMPORT_PREFIX}/./libexec/lrelease-pro" )

# Import target "Qt6::lupdate" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lupdate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lupdate PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/bin/lupdate"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lupdate )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lupdate "${_IMPORT_PREFIX}/bin/lupdate" )

# Import target "Qt6::lupdate-pro" for configuration "RelWithDebInfo"
set_property(TARGET Qt6::lupdate-pro APPEND PROPERTY IMPORTED_CONFIGURATIONS RELWITHDEBINFO)
set_target_properties(Qt6::lupdate-pro PROPERTIES
  IMPORTED_LOCATION_RELWITHDEBINFO "${_IMPORT_PREFIX}/./libexec/lupdate-pro"
  )

list(APPEND _IMPORT_CHECK_TARGETS Qt6::lupdate-pro )
list(APPEND _IMPORT_CHECK_FILES_FOR_Qt6::lupdate-pro "${_IMPORT_PREFIX}/./libexec/lupdate-pro" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
